@@ -173,6 +173,11 @@ class AppT(HasName):
         """send `message` to message queue"""
         ...
 
+    @abc.abstractmethod
+    def ergo_send(self, results, message=None, args=None):
+        """send `message` to ergo p2p"""
+        ...
+
     @property
     @abc.abstractmethod
     def vars(self):
